@@ -5,7 +5,7 @@ import datetime as dt
 import numpy as np
 import astropy.units as u
 from astropy.time import Time
-from astropy.coordinates import Galactic, SkyCoord, get_sun, get_moon
+from astropy.coordinates import Galactic, SkyCoord, get_sun, get_body
 from astropy.utils import minversion
 import pytest
 
@@ -22,6 +22,8 @@ from ..constraints import (AltitudeConstraint, AirmassConstraint, AtNightConstra
                            PrimaryEclipseConstraint, SecondaryEclipseConstraint,
                            is_event_observable)
 from ..periodic import EclipsingSystem
+from ..exceptions import MissingConstraintWarning
+
 
 APY_LT104 = not minversion('astropy', '1.0.4')
 
@@ -96,6 +98,17 @@ def test_observability_table():
     assert 'time observable' in stab.colnames
 
 
+def test_altitude_constraint():
+    subaru = Observer.at_site("Subaru")
+    time = Time('2001-02-03 15:35:00')
+    time_range = Time([time, time+3*u.hour])
+
+    constraint = AltitudeConstraint(min=40*u.deg, max=50*u.deg, boolean_constraint=False)
+    results = constraint(subaru, vega, times=time_grid_from_range(time_range))
+    # Check if below min and above max values are 0
+    assert np.all([results != 0][0] == [False, False, True,  True,  False, False])
+
+
 def test_compare_altitude_constraint_and_observer():
     time = Time('2001-02-03 04:05:06')
     time_ranges = [Time([time, time+1*u.hour]) + offset
@@ -191,7 +204,7 @@ def test_moon_separation():
     time = Time('2003-04-05 06:07:08')
     apo = Observer.at_site("APO")
     altaz_frame = apo.altaz(time)
-    moon = get_moon(time, apo.location).transform_to(altaz_frame)
+    moon = get_body("moon", time, apo.location).transform_to(altaz_frame)
     one_deg_away = SkyCoord(az=moon.az, alt=moon.alt+1*u.deg, frame=altaz_frame)
     five_deg_away = SkyCoord(az=moon.az+5*u.deg, alt=moon.alt,
                              frame=altaz_frame)
@@ -376,13 +389,18 @@ def test_months_observable():
     targets = [FixedTarget(coord=coord) for coord in coords]
     constraints = [AltitudeConstraint(min=80*u.deg),
                    AtNightConstraint.twilight_astronomical()]
-    months = months_observable(constraints, obs, targets)
+    time_range = Time(['2014-01-01', '2014-12-31'])
+    months = months_observable(constraints, obs, targets, time_range)
 
     should_be = [set({7, 8, 9, 10, 11, 12}), set({1, 2, 3, 10, 11, 12}),
                  set({1, 2, 3, 4, 5, 6}), set({4, 5, 6, 7, 8, 9})]
 
     assert months == should_be
 
+    with pytest.warns(MissingConstraintWarning):
+        constraints = [AtNightConstraint.twilight_astronomical()]
+        months_observable(constraints, obs, targets, time_range)
+
 
 def test_rescale_minmax():
     a = np.array([2])
